tracer

package
v0.0.0-...-6aee3ff Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 2, 2020 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var IPVersion_name = map[int32]string{
	0: "IP_NOT_USED",
	1: "IPv4",
	2: "IPv6",
}
var IPVersion_value = map[string]int32{
	"IP_NOT_USED": 0,
	"IPv4":        1,
	"IPv6":        2,
}

Functions

func RegisterTracerServer

func RegisterTracerServer(s *grpc.Server, srv TracerServer)

Types

type DNS

type DNS struct {
	Query string `protobuf:"bytes,1,opt,name=query,proto3" json:"query,omitempty"`
	// Return code of the DNS request defined in:
	//   https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-6
	Rcode uint32 `protobuf:"varint,6,opt,name=rcode,proto3" json:"rcode,omitempty"`
	// String representation of qtypes defined in:
	//   https://tools.ietf.org/html/rfc1035#section-3.2.3
	Qtypes []string `protobuf:"bytes,7,rep,name=qtypes,proto3" json:"qtypes,omitempty"`
	// String representation of rrtypes defined in:
	// https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-4
	Rrtypes              []string `protobuf:"bytes,8,rep,name=rrtypes,proto3" json:"rrtypes,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*DNS) Descriptor

func (*DNS) Descriptor() ([]byte, []int)

func (*DNS) GetQtypes

func (m *DNS) GetQtypes() []string

func (*DNS) GetQuery

func (m *DNS) GetQuery() string

func (*DNS) GetRcode

func (m *DNS) GetRcode() uint32

func (*DNS) GetRrtypes

func (m *DNS) GetRrtypes() []string

func (*DNS) ProtoMessage

func (*DNS) ProtoMessage()

func (*DNS) Reset

func (m *DNS) Reset()

func (*DNS) String

func (m *DNS) String() string

func (*DNS) XXX_DiscardUnknown

func (m *DNS) XXX_DiscardUnknown()

func (*DNS) XXX_Marshal

func (m *DNS) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*DNS) XXX_Merge

func (m *DNS) XXX_Merge(src proto.Message)

func (*DNS) XXX_Size

func (m *DNS) XXX_Size() int

func (*DNS) XXX_Unmarshal

func (m *DNS) XXX_Unmarshal(b []byte) error

type Endpoint

type Endpoint struct {
	Namespace            string            `protobuf:"bytes,1,opt,name=namespace,proto3" json:"namespace,omitempty"`
	Name                 string            `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	Labels               map[string]string `` /* 153-byte string literal not displayed */
	XXX_NoUnkeyedLiteral struct{}          `json:"-"`
	XXX_unrecognized     []byte            `json:"-"`
	XXX_sizecache        int32             `json:"-"`
}

func (*Endpoint) Descriptor

func (*Endpoint) Descriptor() ([]byte, []int)

func (*Endpoint) GetLabels

func (m *Endpoint) GetLabels() map[string]string

func (*Endpoint) GetName

func (m *Endpoint) GetName() string

func (*Endpoint) GetNamespace

func (m *Endpoint) GetNamespace() string

func (*Endpoint) ProtoMessage

func (*Endpoint) ProtoMessage()

func (*Endpoint) Reset

func (m *Endpoint) Reset()

func (*Endpoint) String

func (m *Endpoint) String() string

func (*Endpoint) XXX_DiscardUnknown

func (m *Endpoint) XXX_DiscardUnknown()

func (*Endpoint) XXX_Marshal

func (m *Endpoint) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Endpoint) XXX_Merge

func (m *Endpoint) XXX_Merge(src proto.Message)

func (*Endpoint) XXX_Size

func (m *Endpoint) XXX_Size() int

func (*Endpoint) XXX_Unmarshal

func (m *Endpoint) XXX_Unmarshal(b []byte) error

type GetTracesRequest

type GetTracesRequest struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*GetTracesRequest) Descriptor

func (*GetTracesRequest) Descriptor() ([]byte, []int)

func (*GetTracesRequest) ProtoMessage

func (*GetTracesRequest) ProtoMessage()

func (*GetTracesRequest) Reset

func (m *GetTracesRequest) Reset()

func (*GetTracesRequest) String

func (m *GetTracesRequest) String() string

func (*GetTracesRequest) XXX_DiscardUnknown

func (m *GetTracesRequest) XXX_DiscardUnknown()

func (*GetTracesRequest) XXX_Marshal

func (m *GetTracesRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*GetTracesRequest) XXX_Merge

func (m *GetTracesRequest) XXX_Merge(src proto.Message)

func (*GetTracesRequest) XXX_Size

func (m *GetTracesRequest) XXX_Size() int

func (*GetTracesRequest) XXX_Unmarshal

func (m *GetTracesRequest) XXX_Unmarshal(b []byte) error

type GetTracesResponse

type GetTracesResponse struct {
	Trace                *Trace   `protobuf:"bytes,1,opt,name=trace,proto3" json:"trace,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*GetTracesResponse) Descriptor

func (*GetTracesResponse) Descriptor() ([]byte, []int)

func (*GetTracesResponse) GetTrace

func (m *GetTracesResponse) GetTrace() *Trace

func (*GetTracesResponse) ProtoMessage

func (*GetTracesResponse) ProtoMessage()

func (*GetTracesResponse) Reset

func (m *GetTracesResponse) Reset()

func (*GetTracesResponse) String

func (m *GetTracesResponse) String() string

func (*GetTracesResponse) XXX_DiscardUnknown

func (m *GetTracesResponse) XXX_DiscardUnknown()

func (*GetTracesResponse) XXX_Marshal

func (m *GetTracesResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*GetTracesResponse) XXX_Merge

func (m *GetTracesResponse) XXX_Merge(src proto.Message)

func (*GetTracesResponse) XXX_Size

func (m *GetTracesResponse) XXX_Size() int

func (*GetTracesResponse) XXX_Unmarshal

func (m *GetTracesResponse) XXX_Unmarshal(b []byte) error

type HTTP

type HTTP struct {
	Code                 uint32        `protobuf:"varint,1,opt,name=code,proto3" json:"code,omitempty"`
	Method               string        `protobuf:"bytes,2,opt,name=method,proto3" json:"method,omitempty"`
	Url                  string        `protobuf:"bytes,3,opt,name=url,proto3" json:"url,omitempty"`
	Protocol             string        `protobuf:"bytes,4,opt,name=protocol,proto3" json:"protocol,omitempty"`
	Headers              []*HTTPHeader `protobuf:"bytes,5,rep,name=headers,proto3" json:"headers,omitempty"`
	XXX_NoUnkeyedLiteral struct{}      `json:"-"`
	XXX_unrecognized     []byte        `json:"-"`
	XXX_sizecache        int32         `json:"-"`
}

func (*HTTP) Descriptor

func (*HTTP) Descriptor() ([]byte, []int)

func (*HTTP) GetCode

func (m *HTTP) GetCode() uint32

func (*HTTP) GetHeaders

func (m *HTTP) GetHeaders() []*HTTPHeader

func (*HTTP) GetMethod

func (m *HTTP) GetMethod() string

func (*HTTP) GetProtocol

func (m *HTTP) GetProtocol() string

func (*HTTP) GetUrl

func (m *HTTP) GetUrl() string

func (*HTTP) ProtoMessage

func (*HTTP) ProtoMessage()

func (*HTTP) Reset

func (m *HTTP) Reset()

func (*HTTP) String

func (m *HTTP) String() string

func (*HTTP) XXX_DiscardUnknown

func (m *HTTP) XXX_DiscardUnknown()

func (*HTTP) XXX_Marshal

func (m *HTTP) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*HTTP) XXX_Merge

func (m *HTTP) XXX_Merge(src proto.Message)

func (*HTTP) XXX_Size

func (m *HTTP) XXX_Size() int

func (*HTTP) XXX_Unmarshal

func (m *HTTP) XXX_Unmarshal(b []byte) error

type HTTPHeader

type HTTPHeader struct {
	Key                  string   `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Value                string   `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*HTTPHeader) Descriptor

func (*HTTPHeader) Descriptor() ([]byte, []int)

func (*HTTPHeader) GetKey

func (m *HTTPHeader) GetKey() string

func (*HTTPHeader) GetValue

func (m *HTTPHeader) GetValue() string

func (*HTTPHeader) ProtoMessage

func (*HTTPHeader) ProtoMessage()

func (*HTTPHeader) Reset

func (m *HTTPHeader) Reset()

func (*HTTPHeader) String

func (m *HTTPHeader) String() string

func (*HTTPHeader) XXX_DiscardUnknown

func (m *HTTPHeader) XXX_DiscardUnknown()

func (*HTTPHeader) XXX_Marshal

func (m *HTTPHeader) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*HTTPHeader) XXX_Merge

func (m *HTTPHeader) XXX_Merge(src proto.Message)

func (*HTTPHeader) XXX_Size

func (m *HTTPHeader) XXX_Size() int

func (*HTTPHeader) XXX_Unmarshal

func (m *HTTPHeader) XXX_Unmarshal(b []byte) error

type ICMPv4

type ICMPv4 struct {
	Type                 uint32   `protobuf:"varint,1,opt,name=type,proto3" json:"type,omitempty"`
	Code                 uint32   `protobuf:"varint,2,opt,name=code,proto3" json:"code,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*ICMPv4) Descriptor

func (*ICMPv4) Descriptor() ([]byte, []int)

func (*ICMPv4) GetCode

func (m *ICMPv4) GetCode() uint32

func (*ICMPv4) GetType

func (m *ICMPv4) GetType() uint32

func (*ICMPv4) ProtoMessage

func (*ICMPv4) ProtoMessage()

func (*ICMPv4) Reset

func (m *ICMPv4) Reset()

func (*ICMPv4) String

func (m *ICMPv4) String() string

func (*ICMPv4) XXX_DiscardUnknown

func (m *ICMPv4) XXX_DiscardUnknown()

func (*ICMPv4) XXX_Marshal

func (m *ICMPv4) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ICMPv4) XXX_Merge

func (m *ICMPv4) XXX_Merge(src proto.Message)

func (*ICMPv4) XXX_Size

func (m *ICMPv4) XXX_Size() int

func (*ICMPv4) XXX_Unmarshal

func (m *ICMPv4) XXX_Unmarshal(b []byte) error

type ICMPv6

type ICMPv6 struct {
	Type                 uint32   `protobuf:"varint,1,opt,name=type,proto3" json:"type,omitempty"`
	Code                 uint32   `protobuf:"varint,2,opt,name=code,proto3" json:"code,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*ICMPv6) Descriptor

func (*ICMPv6) Descriptor() ([]byte, []int)

func (*ICMPv6) GetCode

func (m *ICMPv6) GetCode() uint32

func (*ICMPv6) GetType

func (m *ICMPv6) GetType() uint32

func (*ICMPv6) ProtoMessage

func (*ICMPv6) ProtoMessage()

func (*ICMPv6) Reset

func (m *ICMPv6) Reset()

func (*ICMPv6) String

func (m *ICMPv6) String() string

func (*ICMPv6) XXX_DiscardUnknown

func (m *ICMPv6) XXX_DiscardUnknown()

func (*ICMPv6) XXX_Marshal

func (m *ICMPv6) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ICMPv6) XXX_Merge

func (m *ICMPv6) XXX_Merge(src proto.Message)

func (*ICMPv6) XXX_Size

func (m *ICMPv6) XXX_Size() int

func (*ICMPv6) XXX_Unmarshal

func (m *ICMPv6) XXX_Unmarshal(b []byte) error

type IP

type IP struct {
	Source               string    `protobuf:"bytes,1,opt,name=source,proto3" json:"source,omitempty"`
	Destination          string    `protobuf:"bytes,2,opt,name=destination,proto3" json:"destination,omitempty"`
	IpVersion            IPVersion `protobuf:"varint,3,opt,name=ipVersion,proto3,enum=tracer.IPVersion" json:"ipVersion,omitempty"`
	XXX_NoUnkeyedLiteral struct{}  `json:"-"`
	XXX_unrecognized     []byte    `json:"-"`
	XXX_sizecache        int32     `json:"-"`
}

func (*IP) Descriptor

func (*IP) Descriptor() ([]byte, []int)

func (*IP) GetDestination

func (m *IP) GetDestination() string

func (*IP) GetIpVersion

func (m *IP) GetIpVersion() IPVersion

func (*IP) GetSource

func (m *IP) GetSource() string

func (*IP) ProtoMessage

func (*IP) ProtoMessage()

func (*IP) Reset

func (m *IP) Reset()

func (*IP) String

func (m *IP) String() string

func (*IP) XXX_DiscardUnknown

func (m *IP) XXX_DiscardUnknown()

func (*IP) XXX_Marshal

func (m *IP) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*IP) XXX_Merge

func (m *IP) XXX_Merge(src proto.Message)

func (*IP) XXX_Size

func (m *IP) XXX_Size() int

func (*IP) XXX_Unmarshal

func (m *IP) XXX_Unmarshal(b []byte) error

type IPVersion

type IPVersion int32
const (
	IPVersion_IP_NOT_USED IPVersion = 0
	IPVersion_IPv4        IPVersion = 1
	IPVersion_IPv6        IPVersion = 2
)

func (IPVersion) EnumDescriptor

func (IPVersion) EnumDescriptor() ([]byte, []int)

func (IPVersion) String

func (x IPVersion) String() string

type Layer4

type Layer4 struct {
	// Types that are valid to be assigned to Protocol:
	//	*Layer4_TCP
	//	*Layer4_UDP
	//	*Layer4_ICMPv4
	//	*Layer4_ICMPv6
	Protocol             isLayer4_Protocol `protobuf_oneof:"protocol"`
	XXX_NoUnkeyedLiteral struct{}          `json:"-"`
	XXX_unrecognized     []byte            `json:"-"`
	XXX_sizecache        int32             `json:"-"`
}

func (*Layer4) Descriptor

func (*Layer4) Descriptor() ([]byte, []int)

func (*Layer4) GetICMPv4

func (m *Layer4) GetICMPv4() *ICMPv4

func (*Layer4) GetICMPv6

func (m *Layer4) GetICMPv6() *ICMPv6

func (*Layer4) GetProtocol

func (m *Layer4) GetProtocol() isLayer4_Protocol

func (*Layer4) GetTCP

func (m *Layer4) GetTCP() *TCP

func (*Layer4) GetUDP

func (m *Layer4) GetUDP() *UDP

func (*Layer4) ProtoMessage

func (*Layer4) ProtoMessage()

func (*Layer4) Reset

func (m *Layer4) Reset()

func (*Layer4) String

func (m *Layer4) String() string

func (*Layer4) XXX_DiscardUnknown

func (m *Layer4) XXX_DiscardUnknown()

func (*Layer4) XXX_Marshal

func (m *Layer4) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Layer4) XXX_Merge

func (m *Layer4) XXX_Merge(src proto.Message)

func (*Layer4) XXX_OneofWrappers

func (*Layer4) XXX_OneofWrappers() []interface{}

XXX_OneofWrappers is for the internal use of the proto package.

func (*Layer4) XXX_Size

func (m *Layer4) XXX_Size() int

func (*Layer4) XXX_Unmarshal

func (m *Layer4) XXX_Unmarshal(b []byte) error

type Layer4_ICMPv4

type Layer4_ICMPv4 struct {
	ICMPv4 *ICMPv4 `protobuf:"bytes,3,opt,name=ICMPv4,proto3,oneof"`
}

type Layer4_ICMPv6

type Layer4_ICMPv6 struct {
	ICMPv6 *ICMPv6 `protobuf:"bytes,4,opt,name=ICMPv6,proto3,oneof"`
}

type Layer4_TCP

type Layer4_TCP struct {
	TCP *TCP `protobuf:"bytes,1,opt,name=TCP,proto3,oneof"`
}

type Layer4_UDP

type Layer4_UDP struct {
	UDP *UDP `protobuf:"bytes,2,opt,name=UDP,proto3,oneof"`
}

type Layer7

type Layer7 struct {
	// Types that are valid to be assigned to Record:
	//	*Layer7_Dns
	//	*Layer7_Http
	Record               isLayer7_Record `protobuf_oneof:"record"`
	XXX_NoUnkeyedLiteral struct{}        `json:"-"`
	XXX_unrecognized     []byte          `json:"-"`
	XXX_sizecache        int32           `json:"-"`
}

func (*Layer7) Descriptor

func (*Layer7) Descriptor() ([]byte, []int)

func (*Layer7) GetDns

func (m *Layer7) GetDns() *DNS

func (*Layer7) GetHttp

func (m *Layer7) GetHttp() *HTTP

func (*Layer7) GetRecord

func (m *Layer7) GetRecord() isLayer7_Record

func (*Layer7) ProtoMessage

func (*Layer7) ProtoMessage()

func (*Layer7) Reset

func (m *Layer7) Reset()

func (*Layer7) String

func (m *Layer7) String() string

func (*Layer7) XXX_DiscardUnknown

func (m *Layer7) XXX_DiscardUnknown()

func (*Layer7) XXX_Marshal

func (m *Layer7) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Layer7) XXX_Merge

func (m *Layer7) XXX_Merge(src proto.Message)

func (*Layer7) XXX_OneofWrappers

func (*Layer7) XXX_OneofWrappers() []interface{}

XXX_OneofWrappers is for the internal use of the proto package.

func (*Layer7) XXX_Size

func (m *Layer7) XXX_Size() int

func (*Layer7) XXX_Unmarshal

func (m *Layer7) XXX_Unmarshal(b []byte) error

type Layer7_Dns

type Layer7_Dns struct {
	Dns *DNS `protobuf:"bytes,100,opt,name=dns,proto3,oneof"`
}

type Layer7_Http

type Layer7_Http struct {
	Http *HTTP `protobuf:"bytes,101,opt,name=http,proto3,oneof"`
}

type ServerStatusRequest

type ServerStatusRequest struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*ServerStatusRequest) Descriptor

func (*ServerStatusRequest) Descriptor() ([]byte, []int)

func (*ServerStatusRequest) ProtoMessage

func (*ServerStatusRequest) ProtoMessage()

func (*ServerStatusRequest) Reset

func (m *ServerStatusRequest) Reset()

func (*ServerStatusRequest) String

func (m *ServerStatusRequest) String() string

func (*ServerStatusRequest) XXX_DiscardUnknown

func (m *ServerStatusRequest) XXX_DiscardUnknown()

func (*ServerStatusRequest) XXX_Marshal

func (m *ServerStatusRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ServerStatusRequest) XXX_Merge

func (m *ServerStatusRequest) XXX_Merge(src proto.Message)

func (*ServerStatusRequest) XXX_Size

func (m *ServerStatusRequest) XXX_Size() int

func (*ServerStatusRequest) XXX_Unmarshal

func (m *ServerStatusRequest) XXX_Unmarshal(b []byte) error

type ServerStatusResponse

type ServerStatusResponse struct {
	NumFlows             uint64   `protobuf:"varint,1,opt,name=num_flows,json=numFlows,proto3" json:"num_flows,omitempty"`
	MaxFlows             uint64   `protobuf:"varint,2,opt,name=max_flows,json=maxFlows,proto3" json:"max_flows,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*ServerStatusResponse) Descriptor

func (*ServerStatusResponse) Descriptor() ([]byte, []int)

func (*ServerStatusResponse) GetMaxFlows

func (m *ServerStatusResponse) GetMaxFlows() uint64

func (*ServerStatusResponse) GetNumFlows

func (m *ServerStatusResponse) GetNumFlows() uint64

func (*ServerStatusResponse) ProtoMessage

func (*ServerStatusResponse) ProtoMessage()

func (*ServerStatusResponse) Reset

func (m *ServerStatusResponse) Reset()

func (*ServerStatusResponse) String

func (m *ServerStatusResponse) String() string

func (*ServerStatusResponse) XXX_DiscardUnknown

func (m *ServerStatusResponse) XXX_DiscardUnknown()

func (*ServerStatusResponse) XXX_Marshal

func (m *ServerStatusResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ServerStatusResponse) XXX_Merge

func (m *ServerStatusResponse) XXX_Merge(src proto.Message)

func (*ServerStatusResponse) XXX_Size

func (m *ServerStatusResponse) XXX_Size() int

func (*ServerStatusResponse) XXX_Unmarshal

func (m *ServerStatusResponse) XXX_Unmarshal(b []byte) error

type TCP

type TCP struct {
	SourcePort           uint32    `protobuf:"varint,1,opt,name=source_port,json=sourcePort,proto3" json:"source_port,omitempty"`
	DestinationPort      uint32    `protobuf:"varint,2,opt,name=destination_port,json=destinationPort,proto3" json:"destination_port,omitempty"`
	Flags                *TCPFlags `protobuf:"bytes,3,opt,name=flags,proto3" json:"flags,omitempty"`
	XXX_NoUnkeyedLiteral struct{}  `json:"-"`
	XXX_unrecognized     []byte    `json:"-"`
	XXX_sizecache        int32     `json:"-"`
}

func (*TCP) Descriptor

func (*TCP) Descriptor() ([]byte, []int)

func (*TCP) GetDestinationPort

func (m *TCP) GetDestinationPort() uint32

func (*TCP) GetFlags

func (m *TCP) GetFlags() *TCPFlags

func (*TCP) GetSourcePort

func (m *TCP) GetSourcePort() uint32

func (*TCP) ProtoMessage

func (*TCP) ProtoMessage()

func (*TCP) Reset

func (m *TCP) Reset()

func (*TCP) String

func (m *TCP) String() string

func (*TCP) XXX_DiscardUnknown

func (m *TCP) XXX_DiscardUnknown()

func (*TCP) XXX_Marshal

func (m *TCP) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*TCP) XXX_Merge

func (m *TCP) XXX_Merge(src proto.Message)

func (*TCP) XXX_Size

func (m *TCP) XXX_Size() int

func (*TCP) XXX_Unmarshal

func (m *TCP) XXX_Unmarshal(b []byte) error

type TCPFlags

type TCPFlags struct {
	FIN                  bool     `protobuf:"varint,1,opt,name=FIN,proto3" json:"FIN,omitempty"`
	SYN                  bool     `protobuf:"varint,2,opt,name=SYN,proto3" json:"SYN,omitempty"`
	RST                  bool     `protobuf:"varint,3,opt,name=RST,proto3" json:"RST,omitempty"`
	PSH                  bool     `protobuf:"varint,4,opt,name=PSH,proto3" json:"PSH,omitempty"`
	ACK                  bool     `protobuf:"varint,5,opt,name=ACK,proto3" json:"ACK,omitempty"`
	URG                  bool     `protobuf:"varint,6,opt,name=URG,proto3" json:"URG,omitempty"`
	ECE                  bool     `protobuf:"varint,7,opt,name=ECE,proto3" json:"ECE,omitempty"`
	CWR                  bool     `protobuf:"varint,8,opt,name=CWR,proto3" json:"CWR,omitempty"`
	NS                   bool     `protobuf:"varint,9,opt,name=NS,proto3" json:"NS,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*TCPFlags) Descriptor

func (*TCPFlags) Descriptor() ([]byte, []int)

func (*TCPFlags) GetACK

func (m *TCPFlags) GetACK() bool

func (*TCPFlags) GetCWR

func (m *TCPFlags) GetCWR() bool

func (*TCPFlags) GetECE

func (m *TCPFlags) GetECE() bool

func (*TCPFlags) GetFIN

func (m *TCPFlags) GetFIN() bool

func (*TCPFlags) GetNS

func (m *TCPFlags) GetNS() bool

func (*TCPFlags) GetPSH

func (m *TCPFlags) GetPSH() bool

func (*TCPFlags) GetRST

func (m *TCPFlags) GetRST() bool

func (*TCPFlags) GetSYN

func (m *TCPFlags) GetSYN() bool

func (*TCPFlags) GetURG

func (m *TCPFlags) GetURG() bool

func (*TCPFlags) ProtoMessage

func (*TCPFlags) ProtoMessage()

func (*TCPFlags) Reset

func (m *TCPFlags) Reset()

func (*TCPFlags) String

func (m *TCPFlags) String() string

func (*TCPFlags) XXX_DiscardUnknown

func (m *TCPFlags) XXX_DiscardUnknown()

func (*TCPFlags) XXX_Marshal

func (m *TCPFlags) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*TCPFlags) XXX_Merge

func (m *TCPFlags) XXX_Merge(src proto.Message)

func (*TCPFlags) XXX_Size

func (m *TCPFlags) XXX_Size() int

func (*TCPFlags) XXX_Unmarshal

func (m *TCPFlags) XXX_Unmarshal(b []byte) error

type Trace

type Trace struct {
	Time                 *timestamp.Timestamp `protobuf:"bytes,1,opt,name=time,proto3" json:"time,omitempty"`
	IP                   *IP                  `protobuf:"bytes,5,opt,name=IP,proto3" json:"IP,omitempty"`
	L4                   *Layer4              `protobuf:"bytes,6,opt,name=l4,proto3" json:"l4,omitempty"`
	L7                   *Layer7              `protobuf:"bytes,15,opt,name=l7,proto3" json:"l7,omitempty"`
	Source               *Endpoint            `protobuf:"bytes,8,opt,name=source,proto3" json:"source,omitempty"`
	Destination          *Endpoint            `protobuf:"bytes,9,opt,name=destination,proto3" json:"destination,omitempty"`
	NodeName             string               `protobuf:"bytes,11,opt,name=node_name,json=nodeName,proto3" json:"node_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{}             `json:"-"`
	XXX_unrecognized     []byte               `json:"-"`
	XXX_sizecache        int32                `json:"-"`
}

func (*Trace) Descriptor

func (*Trace) Descriptor() ([]byte, []int)

func (*Trace) GetDestination

func (m *Trace) GetDestination() *Endpoint

func (*Trace) GetIP

func (m *Trace) GetIP() *IP

func (*Trace) GetL4

func (m *Trace) GetL4() *Layer4

func (*Trace) GetL7

func (m *Trace) GetL7() *Layer7

func (*Trace) GetNodeName

func (m *Trace) GetNodeName() string

func (*Trace) GetSource

func (m *Trace) GetSource() *Endpoint

func (*Trace) GetTime

func (m *Trace) GetTime() *timestamp.Timestamp

func (*Trace) ProtoMessage

func (*Trace) ProtoMessage()

func (*Trace) Reset

func (m *Trace) Reset()

func (*Trace) String

func (m *Trace) String() string

func (*Trace) XXX_DiscardUnknown

func (m *Trace) XXX_DiscardUnknown()

func (*Trace) XXX_Marshal

func (m *Trace) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Trace) XXX_Merge

func (m *Trace) XXX_Merge(src proto.Message)

func (*Trace) XXX_Size

func (m *Trace) XXX_Size() int

func (*Trace) XXX_Unmarshal

func (m *Trace) XXX_Unmarshal(b []byte) error

type TracerClient

type TracerClient interface {
	GetTraces(ctx context.Context, in *GetTracesRequest, opts ...grpc.CallOption) (Tracer_GetTracesClient, error)
	ServerStatus(ctx context.Context, in *ServerStatusRequest, opts ...grpc.CallOption) (*ServerStatusResponse, error)
}

TracerClient is the client API for Tracer service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

func NewTracerClient

func NewTracerClient(cc grpc.ClientConnInterface) TracerClient

type TracerServer

type TracerServer interface {
	GetTraces(*GetTracesRequest, Tracer_GetTracesServer) error
	ServerStatus(context.Context, *ServerStatusRequest) (*ServerStatusResponse, error)
}

TracerServer is the server API for Tracer service.

type Tracer_GetTracesClient

type Tracer_GetTracesClient interface {
	Recv() (*GetTracesResponse, error)
	grpc.ClientStream
}

type Tracer_GetTracesServer

type Tracer_GetTracesServer interface {
	Send(*GetTracesResponse) error
	grpc.ServerStream
}

type UDP

type UDP struct {
	SourcePort           uint32   `protobuf:"varint,1,opt,name=source_port,json=sourcePort,proto3" json:"source_port,omitempty"`
	DestinationPort      uint32   `protobuf:"varint,2,opt,name=destination_port,json=destinationPort,proto3" json:"destination_port,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*UDP) Descriptor

func (*UDP) Descriptor() ([]byte, []int)

func (*UDP) GetDestinationPort

func (m *UDP) GetDestinationPort() uint32

func (*UDP) GetSourcePort

func (m *UDP) GetSourcePort() uint32

func (*UDP) ProtoMessage

func (*UDP) ProtoMessage()

func (*UDP) Reset

func (m *UDP) Reset()

func (*UDP) String

func (m *UDP) String() string

func (*UDP) XXX_DiscardUnknown

func (m *UDP) XXX_DiscardUnknown()

func (*UDP) XXX_Marshal

func (m *UDP) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*UDP) XXX_Merge

func (m *UDP) XXX_Merge(src proto.Message)

func (*UDP) XXX_Size

func (m *UDP) XXX_Size() int

func (*UDP) XXX_Unmarshal

func (m *UDP) XXX_Unmarshal(b []byte) error

type UnimplementedTracerServer

type UnimplementedTracerServer struct {
}

UnimplementedTracerServer can be embedded to have forward compatible implementations.

func (*UnimplementedTracerServer) GetTraces

func (*UnimplementedTracerServer) ServerStatus

Jump to